@@ -54,7 +54,7 @@ class FieldsConverter:
         :param to_db:
         :param debug: show debug text
         :param tables: converter only for list of tables. Will process more rapidly
-        :param advanced_features: 0 - get sizes of text, 1 - to create partitions , 2 - to crete_sort_fields, 3 - check text_fields_size
+        :param advanced_features: 0 - get sizes of text, 1 - to primary key constraint
         """
         self.advanced_features = advanced_features or []
         self.tables = tables or []
