@@ -120,6 +120,7 @@ class FieldsConverterOneWay:
             return item
         if item[key] is None:
             return item
+
         type_python = self.__get_python_type(fields[key])
         if type_python == "int":
             item[key] = int(item[key])
@@ -127,7 +128,7 @@ class FieldsConverterOneWay:
             item[key] = float(item[key])
         elif type_python == "json":
             item[key] = json.dumps(item[key])
-        elif type == "bool":
+        elif type_python == "bool":
             item[key] = bool(item[key])
         else:
             item[key] = str(item[key])
